import { Component, OnInit } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { User } from '../../../models/user.model';
import { NotificationService } from '../../../services/notification.service';
import { OrientationService } from '../../../services/orientation.service';
import { ProfileService } from '../../services/profile.service';

@Component({
  selector: 'app-orientation-details',
  templateUrl: './orientation-details.component.html',
  styleUrls: ['./orientation-details.component.scss'],
})
export class OrientationDetailsComponent implements OnInit {
  constructor(
    private route: ActivatedRoute,
    public orientationService: OrientationService,
    private notificationService: NotificationService,
    private profileService: ProfileService,
  ) {}

  public orientation;
  public isModalOpenned = false;
  public userProfile: User;
  public isEditMode = false;
  public from: string;

  ngOnInit(): void {
    this.route.queryParams.subscribe((params) => {
      this.from = params['from'];
    });

    this.route.params.subscribe((urlParams) => {
      const orientationId = urlParams.id || '';
      if (orientationId) {
        this.orientationService.getOrientation(orientationId).subscribe((orientation) => {
          this.orientation = orientation;
        });
      }
    });
    this.profileService.getProfile().then((profile) => {
      this.userProfile = new User(profile);
    });
  }

  public goBack(): void {
    history.back();
  }

  public showModal(): void {
    this.isModalOpenned = true;
  }

  public closeOrientation(event): void {
    if (event) {
      // close orientation
      // wip test patch
      this.patchOrientation({
        status: 'completed',
        closingComment: 'closing comment',
        closingDate: new Date(),
        modifiedBy: this.userProfile._id,
      });
    }
    this.isModalOpenned = false;
  }

  public setOrientationStatus(status): void {
    // TODO : patch status
  }

  public editOrientation(): void {
    // TODO : edit orientation
    if (this.isEditMode) {
      // wip test patch
      this.patchOrientation({
        // status: 'completed',
        processingComment: 'processing comment',
        modifiedBy: this.userProfile._id,
      });
    }

    this.isEditMode = !this.isEditMode;
  }

  public setProcessingComment(comment): void {
    // TODO : patch comment
  }

  private patchOrientation(updatedFields): void {
    this.orientationService.patchOrientation(this.orientation._id, updatedFields).subscribe({
      next: (orientation) => {
        this.notificationService.showSuccess("L'orientation a bien été mise à jour.");
        // Display the updated values on the orientation details page
        this.orientation = orientation;
      },
      error: () => {
        this.notificationService.showErrorPleaseRetry(
          "Une erreur s'est produite lors de la mise à jour de l'orientation.",
        );
      },
    });
  }
}
