import { A11yModule } from '@angular/cdk/a11y';
import { CommonModule } from '@angular/common';
import { HttpClientModule } from '@angular/common/http';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
import type { Meta, StoryObj } from '@storybook/angular';
import { moduleMetadata } from '@storybook/angular';
import { MoreFiltersComponent } from '../../../structure-list/components/more-filters/more-filters.component';
import { Module } from '../../../structure-list/models/module.model';
import { SearchService } from '../../../structure-list/services/search.service';
import { ButtonComponent } from '../button/button.component';
import { LabelCheckboxComponent } from '../checkbox-label/label-checkbox.component';
import { CheckboxComponent } from '../checkbox/checkbox.component';
import { CollapseContentComponent } from '../collapse/collapse-content/collapse-content.component';
import { CollapseHeaderComponent } from '../collapse/collapse-header/collapse-header.component';
import { CollapseComponent } from '../collapse/collapse.component';
import { RadioComponent } from '../radio/radio.component';
import { SvgIconComponent } from '../svg-icon/svg-icon.component';
import { CollapsableFilterComponent } from './collapsable-filter.component';

// More on how to set up stories at: https://storybook.js.org/docs/angular/writing-stories/introduction
const meta: Meta<CollapsableFilterComponent> = {
  title: 'Filters/Collapsable filter',
  component: CollapsableFilterComponent,
  tags: ['autodocs'],
  decorators: [
    moduleMetadata({
      declarations: [
        SvgIconComponent,
        MoreFiltersComponent,
        ButtonComponent,
        CheckboxComponent,
        LabelCheckboxComponent,
        CollapseComponent,
        CollapseHeaderComponent,
        CollapseContentComponent,
        RadioComponent,
      ],
      imports: [CommonModule, HttpClientModule, A11yModule, BrowserAnimationsModule],
      providers: [SearchService],
    }),
  ],
  argTypes: {},
};

export default meta;
type Story = StoryObj<CollapsableFilterComponent>;

export const CollapsableFilter: Story = {
  args: {
    label: 'Filtre',
    categories: [
      {
        id: 'category1',
        name: 'Catégorie 1',
        theme: 'Catégorie 1',
        modules: [
          {
            disabled: false,
            name: 'Item 1',
            id: 'item1',
          },
          {
            disabled: false,
            name: 'Item 2',
            id: 'item2',
          },
        ],
      },
    ],
  },
};

export const CollapsableFilterActive: Story = {
  args: {
    ...CollapsableFilter.args,
    checkedModules: [new Module('item1', 'category1', 'item1')],
  },
};

export const WithMultipleCategories: Story = {
  args: {
    ...CollapsableFilter.args,
    categories: [
      {
        id: 'category1',
        name: 'Catégorie 1',
        theme: 'Catégorie 1',
        modules: [
          {
            disabled: false,
            name: 'Item 1',
            id: 'item1',
          },
          {
            disabled: false,
            name: 'Item 2',
            id: 'item2',
          },
        ],
      },
      {
        id: 'category2',
        name: 'Catégorie 2',
        theme: 'Catégorie 2',
        modules: [
          {
            disabled: false,
            name: 'Item 3',
            id: 'item3',
          },
          {
            disabled: false,
            name: 'Item 4',
            id: 'item4',
          },
        ],
      },
    ],
  },
};

export const CollapsableFilterRadio: Story = {
  args: {
    ...CollapsableFilter.args,
    isRadio: true,
  },
};
