import { HttpClient } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { BehaviorSubject, Observable, lastValueFrom } from 'rxjs';
import { map } from 'rxjs/operators';
import { SearchQuery, SearchResults } from '../../annuaire/models/searchQuery.model';
import { Category } from '../models/category.model';
import { Module } from '../models/module.model';

@Injectable({
  providedIn: 'root',
})
export class SearchService {
  public annuaireSearchQuery: SearchQuery;
  public previousResult$ = new BehaviorSubject<SearchResults>({ count: 0, docs: [] });

  constructor(private http: HttpClient) {}

  /**
   * Return repository data for search
   */
  public getCategories(): Observable<Category[]> {
    return this.http.get('/api/categories').pipe(map((data: any[]) => data.map((item) => new Category(item))));
  }
  public getJobs(): Observable<any> {
    return this.http.get('/api/jobs-groups/with-jobs');
  }
  public getEmployers(): Observable<any> {
    return this.http.get('/api/employer');
  }
  public async searchUserRegistry(
    searchTerm: string,
    page: number,
    job?: string[],
    employer?: string[],
    territory?: string[],
    commune?: string[],
    referentsOnly?: boolean,
  ): Promise<SearchResults> {
    const users = await lastValueFrom(
      this.http.post<SearchResults>(`/api/userRegistry/?search=${searchTerm}`, {
        job,
        employer,
        territory,
        commune,
        referentsOnly,
        page,
      }),
    );
    return users;
  }
  public getUserRegistryCount(): Observable<number> {
    return this.http.get<any>(`/api/userRegistry/count`).pipe();
  }
  public getIndex(array: Module[], id: string, categ: string): number {
    return array.findIndex((m: Module) => m.id === id && m.name === categ);
  }
  public getCommunesWithUsers(): Observable<any> {
    return this.http.get<any>('/api/userRegistry/communesWithUsers');
  }
}
